import click
import logging
from aws_profile_manager import Common, Switch

@click.command()
def cli():
    """ Switch default AWS profile in your ~/.aws/credentials """
    common = Common()
    switch = Switch()

    users_home = common.get_users_home()
    all_profiles = common.get_all_profiles(users_home)
    new_default_profile_name = None
    if "default" not in all_profiles:
        logging.warning("There is no [default] profile in your {}/.aws/credentials. It will be automatically created".format(users_home))
    else:
        defaults_backup = switch.get_defaults_backup(all_profiles)
        if defaults_backup:
            logging.warning("Your current default is \033[1m{}\033[0m \n".format(defaults_backup))
        else:
            new_default_profile_name = switch.ask_new_name_for_default_profile(users_home, all_profiles)
            if new_default_profile_name:
                all_profiles = switch.create_backup_for_default(all_profiles, new_default_profile_name)
    new_default = switch.choose_new_default(all_profiles, new_default_profile_name)
    new_profiles_list = common.generate_new_profile_list(all_profiles, new_default)
    common.rewrite_credentials_file(new_profiles_list, users_home)


import unittest
from aws_profile_manager import Common

class TestCommon(unittest.TestCase):
    def setUp(self):
        self.common = Common()
    
    def test_generate_new_profile_list(self):
        test_data = {
                            'default': 
                                {
                                    'aws_access_key_id': 'AKIAYYYYYYYYYYYYYYYY',
                                    'aws_secret_access_key': 'yYyYyYyYyYyYyYyYyYyYyYyYyYyYyYyYyYyYyYyY'
                                },
                            'test1': 
                                {
                                    'aws_access_key_id': 'AKIAZZZZZZZZZZZZZZZZ',
                                    'aws_secret_access_key': 'zZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZ'}
                            }
        expected_output = {
                            'default': 
                                {
                                    'aws_access_key_id': 'AKIAZZZZZZZZZZZZZZZZ',
                                    'aws_secret_access_key': 'zZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZ'
                                },
                            'test1': 
                                {
                                    'aws_access_key_id': 'AKIAZZZZZZZZZZZZZZZZ',
                                    'aws_secret_access_key': 'zZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZzZ'
                                }
                            }
        self.assertDictEqual(self.common.generate_new_profile_list(test_data, 'test1'), expected_output)

    def test_aws_access_key_id_with_valid_value(self):
        self.assertTrue(self.common.aws_access_key_id_is_valid('AKIAAAAAAAAAAAAAAAAA'))

    def test_aws_access_key_id_with_invalid_value(self):
        self.assertFalse(self.common.aws_access_key_id_is_valid('AKIAAAAAAAAAAAAAAAA'))

    def test_aws_secret_access_key_with_valid_value(self):
        self.assertTrue(self.common.aws_secret_access_key_is_valid('Aa1Aa0az00+AzA/01AzZZZz0Z0z0ZzzZZzZZz0zZ'))

    def test_aws_secret_access_key_with_invalid_value(self):
        self.assertFalse(self.common.aws_secret_access_key_is_valid('0ZzzZZzZZz0zZ'))


if __name__ == '__main__':
    unittest.main()


import os
import sys
import click
import logging

from aws_profile_manager._version import __version__

def setup_logging(quiet: bool):
    ''' Function is setting logging configuration '''

    if quiet:
        logging_level = logging.WARNING
    else:
        logging_level = logging.INFO
    logging.basicConfig(format='%(message)s', level=logging_level)

plugin_folder = os.path.join(os.path.dirname(__file__), 'commands')

class MyCLI(click.MultiCommand):
    def list_commands(self, ctx):
        rv = []
        for filename in os.listdir(plugin_folder):
            if filename.startswith('_'):
                continue
            if filename.endswith('.py'):
                rv.append(filename[:-3])
        rv.sort()
        return rv

    def get_command(self, ctx, name):
        ns = {}
        fn = os.path.join(plugin_folder, name + '.py')
        with open(fn) as f:
            code = compile(f.read(), fn, 'exec')
            eval(code, ns, ns)
        return ns['cli']

class RootFlags(object):
    def __init__(self, quiet=None) -> None:
        self.quiet = quiet

@click.group(cls=MyCLI, help='This tool\'s subcommands are loaded from a plugin folder dynamically.')
@click.pass_context
@click.version_option(__version__)
@click.option('-q', '--quiet', help='Less outputs', type=bool, is_flag=True, required=False, default=False)
def cli(ctx, quiet):
    ctx.obj = RootFlags(quiet)
    setup_logging(quiet=quiet)

if __name__ == '__main__':
    try:
        cli()
    except KeyboardInterrupt:
        logging.error("\nProcess has been stopped. Interrupted by user")
        sys.exit(1)


import sys
import re
from os.path import expanduser
from typing import Dict
import configparser
import logging

class Common:
    def get_users_home(self) -> str:
        """ Function returns user's home path """

        return expanduser("~")

    def get_all_profiles(self, users_home: str) -> Dict:
        """ Function receive user's home and parses file .aws/credentials.
            It returns all aws profiles and their credentials in dictionary """
    
        profiles = {}
        config = configparser.ConfigParser()
        config.read('{}/.aws/credentials'.format(users_home))
        sections = config.sections()
        for section in sections:
            section_items = {}
            for key in config[section]:
                section_items[key] = config[section][key]
            profiles[section] = section_items
        return profiles

    def generate_new_profile_list(self, profiles: Dict, new_default: str) -> Dict:
        """ Function receives list of profiles and name of new default. 
            Function returns regenerated list of profiles with new default """

        new_profile_list = {"default": {}}
        for item in profiles[new_default]:
            new_profile_list["default"][item] = profiles[new_default][item]
        profiles.pop('default', None)
        for item in profiles:
            new_profile_list[item] = profiles[item]
        return new_profile_list

    def rewrite_credentials_file(self, new_profiles_list: Dict, users_home: str):
        """ Function receives new_profile_list and users_home. 
            Function revrites credentials file with updated profiles """

        config = configparser.ConfigParser()
        for profile in new_profiles_list:
            config[profile] = new_profiles_list[profile]
        config.write(open('{}/.aws/credentials'.format(users_home), 'w'))

    def aws_access_key_id_is_valid(self, aws_access_key_id):
        ''' The method receives the string with AWS Access Key ID and checks if
        it is valid. If everything is in order it will return True otherwise
        it returns False '''

        if re.match('^AK[A-Z0-9]{18}$', aws_access_key_id):
            return True
        return False

    def aws_secret_access_key_is_valid(self, aws_secret_access_key):
        ''' The method receives the string with AWS Secret Access Key and
        checks if it is valid. If everything is in order it will return True
        otherwise it returns False '''

        if re.match('^[A-Za-z0-9+=/]{40}$', aws_secret_access_key):
            return True
        return False

    def choose_profile(self, profiles, operation) -> str:
        i = 1
        counter = {}
        for profile in profiles:
            counter[i] = profile
            i += 1
        for c in counter:
            print("{}: {}".format(c, counter[c]))
        while True:
            try:
                answer = input(f"\nChoose a number of the profile which you want to {operation}: ")
            except (KeyboardInterrupt, EOFError):
                logging.error("\nProcess has been stopped. Interrupted by user")
                sys.exit(1)
            try:
                return counter[int(answer)]
            except ValueError as e:
                logging.error("Answer \"{}\" is not valid. Please provide number from 1 to {}".format(answer, len(counter)))


from aws_profile_manager.common.common import Common
from aws_profile_manager.profile_switch.switch import Switch
from aws_profile_manager.profile_add.add import Add
from aws_profile_manager.rotate_keys.rotate import Rotate

__all__ = ('Common', 'Switch', 'Add', 'Rotate')


#!/usr/bin/python3

import sys
import argparse
import logging
from aws_profile_manager import Common, Switch

from aws_profile_manager._version import __version__

def setup_logging(quiet: bool, verbose: bool):
    ''' Function is setting logging configuration '''

    if verbose:
        logging_level = logging.INFO
    elif quiet:
        logging_level = logging.ERROR
    else:
        logging_level = logging.WARNING
    logging.basicConfig(format='%(message)s', level=logging_level)

def parse_arguments():
    ''' Function allows to parse arguments from the line input and check if all
    of them are entered correctly '''

    parser = argparse.ArgumentParser(
        description='Manage AWS profile in a fast way',
        epilog='Find more at https://github.com/99stealth/aws-profile-switcher'
    )
    parser.add_argument('--version', action='version',
                        version='%(prog)s \033[0;32m{version}\033[0;0m'.format(version=__version__))

    args = parser.parse_args()
    return args

def main():
    common = Common()
    switch = Switch()

    args = parse_arguments()
    setup_logging(quiet=False, verbose=False)
    users_home = common.get_users_home()
    all_profiles = common.get_all_profiles(users_home)
    new_default_profile_name = None
    if "default" not in all_profiles:
        logging.warning("There is no [default] profile in your {}/.aws/credentials. It will be automatically created".format(users_home))
    else:
        defaults_backup = switch.get_defaults_backup(all_profiles)
        if defaults_backup:
            logging.warning("Your current default is \033[1m{}\033[0m \n".format(defaults_backup))
        else:
            new_default_profile_name = switch.ask_new_name_for_default_profile(users_home, all_profiles)
            if new_default_profile_name:
                all_profiles = switch.create_backup_for_default(all_profiles, new_default_profile_name)
    new_default = switch.choose_new_default(all_profiles, new_default_profile_name)
    new_profiles_list = common.generate_new_profile_list(all_profiles, new_default)
    common.rewrite_credentials_file(new_profiles_list, users_home)

if __name__ == "__main__":
    try:
        main()
    except KeyboardInterrupt:
        logging.error("\nProcess has been stopped. Interrupted by user")
        sys.exit(1)